Range-v3: ranges::v3::view::ints_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Synopsis of methods | Public Member Functions | List of all members
ranges::v3::view::ints_fn Struct Reference
Inheritance diagram for ranges::v3::view::ints_fn:

## Synopsis of methods
constexpr ints_fn | ints {}

## Public Member Functions
template<typename Val , requires = (Integral<Val>())>
iota_view< Val > | operator() (Val value) const
template<typename Val , requires = (Integral<Val>())>
auto | operator() (Val from, Val to) const noexcept(noexcept(decltype(detail::take_exactly_view_< iota_view< Val >, true > {iota_view< Val >{from}, detail::ints_open_distance_(from, to)})(detail::take_exactly_view_< iota_view< Val >, true > {iota_view< Val >{from}, detail::ints_open_distance_(from, to)}))) -> decltype(detail::take_exactly_view_< iota_view< Val >, true >
Public Member Functions inherited from ranges::v3::iota_view< int >
constexpr | iota_view (int from, To to)
Public Member Functions inherited from ranges::v3::view_facade< iota_view< int, To >, finite >
detail::facade_iterator_t< D > | begin ()
| Let `d` be `static_cast<Derived &>(*this)`. Let `b` be `std::as_const(d).begin_cursor()` if that expression is well-formed; otherwise, let `b` be `d.begin_cursor()`. Let `B` be the type of `b`. More...
detail::facade_iterator_t< D const > | begin () const
detail::facade_sentinel_t< D > | end ()
| Let `d` be `static_cast<Derived &>(*this)`. Let `e` be `std::as_const(d).end_cursor()` if that expression is well-formed; otherwise, let `e` be `d.end_cursor()`. Let `E` be the type of `e`. More...
detail::facade_sentinel_t< D const > | end () const
Public Member Functions inherited from ranges::v3::view_interface< iota_view< int, To >, Cardinality >
auto | at (range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n])
| Returns a reference to the element at specified location pos, with bounds checking.
auto | at (range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n])
range_reference_t< D > | back ()
| Access the last element in a range:
range_reference_t< D const > | back () const
constexpr bool | empty () const noexcept
constexpr bool | empty () const noexcept(noexcept(bool(ranges::begin(std::declval< D const & >())==ranges::end(std::declval< D const & >()))))
range_reference_t< D > | front ()
| Access the first element in a range:
range_reference_t< D const > | front () const
constexpr | operator bool () const noexcept(noexcept(ranges::empty(std::declval< D const & >())))
| operator Container ()
| Implicit conversion to something that looks like a container.
| operator Container () const
constexpr auto | operator! () const noexcept(noexcept(decltype(ranges::empty(std::declval< D const & >()))(ranges::empty(std::declval< D const & >())))) -> decltype(ranges::empty(std::declval< D const & >()))
view_interface & | operator= (view_interface &&)=default
view_interface & | operator= (view_interface const &)=default
auto | operator[] (range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n])
| Simple indexing:
auto | operator[] (range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n])
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
| Python-ic slicing:
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
constexpr range_size_type_t< D > | size () const noexcept
| Access the size of the range, if it can be determined:
constexpr range_size_type_t< D > | size () const
| view_interface (view_interface &&)=default
| view_interface (view_interface const &)=default

## Additional Inherited Members
Protected Member Functions inherited from ranges::v3::view_facade< iota_view< int, To >, finite >
iota_view< int, To > | begin_cursor () const
constexpr default_sentinel | end_cursor () const
Protected Member Functions inherited from ranges::v3::view_interface< iota_view< int, To >, Cardinality >
iota_view< int, To > & | derived () noexcept
constexpr iota_view< int, To > const & | derived () const noexcept
Protected Attributes inherited from ranges::v3::view_facade< iota_view< int, To >, finite >
friend | range_access